@@ -2,7 +2,7 @@
 ##
 ##  Call 'rcmdcheck' on a package
 ##
-##  Copyright (C) 2016 - 2020  Dirk Eddelbuettel
+##  Copyright (C) 2016 - 2022  Dirk Eddelbuettel
 ##
 ##  Released under GPL (>= 2)
 
@@ -10,13 +10,14 @@
 library(docopt)
 
 ## configuration for docopt
-doc <- "Usage: rcc.r [-h] [-x] [-c] [-f] [-q] [--args ARGS] [--libpath LIBP] [--repos REPO] [--erroron ERRON] [PATH...]
+doc <- "Usage: rcc.r [-h] [-x] [-c] [-f] [-q] [-v] [--args ARGS] [--libpath LIBP] [--repos REPO] [--erroron ERRON] [PATH...]
 
 -c --as-cran          should '--as-cran' be added to ARGS [default: FALSE]
 -a --args ARGS        additional arguments to be passed to 'R CMD CHECK' [default: ]
 -l --libpath LIBP     additional library path to be used by 'R CMD CHECK' [default: ]
 -r --repos REPO       additional repositories to be used by 'R CMD CHECK' [default: ]
 -f --fast             should vignettes and manuals be skipped [default: FALSE]
+-v --valgrind         should tests run with 'valgrind' debug tool [default: FALSE]
 -e --erroron ERRON    whether to throw an error on failure [default: never]
 -q --quiet            should 'rcmdcheck' be called qietly [default: FALSE]
 -h --help             show this help text
@@ -58,13 +59,16 @@ if (is.null(opt$args)) {         # special treatment for --args and -c
 if (opt$fast) {
     opt$args <- c(opt$args, "--ignore-vignettes", "--no-manual")
 }
+if (opt$valgrind) {
+    opt$args <- c(opt$args, "--use-valgrind")
+}
 
 if (length(opt$PATH) == 0) opt$PATH <- "."      # default argument current directory
 if (is.null(opt$libpath)) opt$libpath <- .libPaths()    # default library pathr
 if (is.null(opt$repos)) opt$repos <- getOption("repos") # default repos
 
 if (requireNamespace("rcmdcheck", quietly=TRUE) == FALSE)
-    stop("This command requires the 'rcmdcheck' package.", call.=FALSE)
+    stop("This command requires the 'rcmdcheck' package.", call. = FALSE)
 
 suppressMessages(library(rcmdcheck))
 
